# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateComputeEnvironmentDetails(object):
    """
    Details for updating a compute environment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateComputeEnvironmentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateComputeEnvironmentDetails.
        :type display_name: str

        :param is_auto_scale_down:
            The value to assign to the is_auto_scale_down property of this UpdateComputeEnvironmentDetails.
        :type is_auto_scale_down: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateComputeEnvironmentDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateComputeEnvironmentDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'is_auto_scale_down': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'is_auto_scale_down': 'isAutoScaleDown',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._is_auto_scale_down = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateComputeEnvironmentDetails.
        The name of the compute environment.


        :return: The display_name of this UpdateComputeEnvironmentDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateComputeEnvironmentDetails.
        The name of the compute environment.


        :param display_name: The display_name of this UpdateComputeEnvironmentDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_auto_scale_down(self):
        """
        Gets the is_auto_scale_down of this UpdateComputeEnvironmentDetails.
        Auto Scale Down


        :return: The is_auto_scale_down of this UpdateComputeEnvironmentDetails.
        :rtype: bool
        """
        return self._is_auto_scale_down

    @is_auto_scale_down.setter
    def is_auto_scale_down(self, is_auto_scale_down):
        """
        Sets the is_auto_scale_down of this UpdateComputeEnvironmentDetails.
        Auto Scale Down


        :param is_auto_scale_down: The is_auto_scale_down of this UpdateComputeEnvironmentDetails.
        :type: bool
        """
        self._is_auto_scale_down = is_auto_scale_down

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateComputeEnvironmentDetails.
        Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateComputeEnvironmentDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateComputeEnvironmentDetails.
        Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateComputeEnvironmentDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateComputeEnvironmentDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateComputeEnvironmentDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateComputeEnvironmentDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateComputeEnvironmentDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
