# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EnableReverseConnectionsDetails(object):
    """
    Details for enabling reverse connections for a private endpoint.
    """

    #: A constant which can be used with the default_dns_resolution_context property of a EnableReverseConnectionsDetails.
    #: This constant has a value of "SERVICE"
    DEFAULT_DNS_RESOLUTION_CONTEXT_SERVICE = "SERVICE"

    #: A constant which can be used with the default_dns_resolution_context property of a EnableReverseConnectionsDetails.
    #: This constant has a value of "CUSTOMER"
    DEFAULT_DNS_RESOLUTION_CONTEXT_CUSTOMER = "CUSTOMER"

    def __init__(self, **kwargs):
        """
        Initializes a new EnableReverseConnectionsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param reverse_connections_source_ips:
            The value to assign to the reverse_connections_source_ips property of this EnableReverseConnectionsDetails.
        :type reverse_connections_source_ips: list[ReverseConnectionsSourceIpDetails]

        :param is_proxy_enabled:
            The value to assign to the is_proxy_enabled property of this EnableReverseConnectionsDetails.
        :type is_proxy_enabled: bool

        :param dns_proxy_ip:
            The value to assign to the dns_proxy_ip property of this EnableReverseConnectionsDetails.
        :type dns_proxy_ip: str

        :param default_dns_resolution_context:
            The value to assign to the default_dns_resolution_context property of this EnableReverseConnectionsDetails.
            Allowed values for this property are: "SERVICE", "CUSTOMER"
        :type default_dns_resolution_context: str

        :param excluded_dns_zones:
            The value to assign to the excluded_dns_zones property of this EnableReverseConnectionsDetails.
        :type excluded_dns_zones: list[str]

        :param service_subnet_id:
            The value to assign to the service_subnet_id property of this EnableReverseConnectionsDetails.
        :type service_subnet_id: str

        """
        self.swagger_types = {
            'reverse_connections_source_ips': 'list[ReverseConnectionsSourceIpDetails]',
            'is_proxy_enabled': 'bool',
            'dns_proxy_ip': 'str',
            'default_dns_resolution_context': 'str',
            'excluded_dns_zones': 'list[str]',
            'service_subnet_id': 'str'
        }

        self.attribute_map = {
            'reverse_connections_source_ips': 'reverseConnectionsSourceIps',
            'is_proxy_enabled': 'isProxyEnabled',
            'dns_proxy_ip': 'dnsProxyIp',
            'default_dns_resolution_context': 'defaultDnsResolutionContext',
            'excluded_dns_zones': 'excludedDnsZones',
            'service_subnet_id': 'serviceSubnetId'
        }

        self._reverse_connections_source_ips = None
        self._is_proxy_enabled = None
        self._dns_proxy_ip = None
        self._default_dns_resolution_context = None
        self._excluded_dns_zones = None
        self._service_subnet_id = None

    @property
    def reverse_connections_source_ips(self):
        """
        Gets the reverse_connections_source_ips of this EnableReverseConnectionsDetails.
        A list of IP addresses in the customer VCN to be used as the source IPs for reverse connection packets
        traveling from the service's VCN to the customer's VCN. If no list is specified or
        an empty list is provided, an IP address will be chosen from the customer subnet's CIDR.


        :return: The reverse_connections_source_ips of this EnableReverseConnectionsDetails.
        :rtype: list[ReverseConnectionsSourceIpDetails]
        """
        return self._reverse_connections_source_ips

    @reverse_connections_source_ips.setter
    def reverse_connections_source_ips(self, reverse_connections_source_ips):
        """
        Sets the reverse_connections_source_ips of this EnableReverseConnectionsDetails.
        A list of IP addresses in the customer VCN to be used as the source IPs for reverse connection packets
        traveling from the service's VCN to the customer's VCN. If no list is specified or
        an empty list is provided, an IP address will be chosen from the customer subnet's CIDR.


        :param reverse_connections_source_ips: The reverse_connections_source_ips of this EnableReverseConnectionsDetails.
        :type: list[ReverseConnectionsSourceIpDetails]
        """
        self._reverse_connections_source_ips = reverse_connections_source_ips

    @property
    def is_proxy_enabled(self):
        """
        Gets the is_proxy_enabled of this EnableReverseConnectionsDetails.
        Whether a DNS proxy should be configured for the reverse connection. If the service
        does not intend to use DNS FQDN to communicate to customer endpoints, set this to `false`.

        Example: `false`


        :return: The is_proxy_enabled of this EnableReverseConnectionsDetails.
        :rtype: bool
        """
        return self._is_proxy_enabled

    @is_proxy_enabled.setter
    def is_proxy_enabled(self, is_proxy_enabled):
        """
        Sets the is_proxy_enabled of this EnableReverseConnectionsDetails.
        Whether a DNS proxy should be configured for the reverse connection. If the service
        does not intend to use DNS FQDN to communicate to customer endpoints, set this to `false`.

        Example: `false`


        :param is_proxy_enabled: The is_proxy_enabled of this EnableReverseConnectionsDetails.
        :type: bool
        """
        self._is_proxy_enabled = is_proxy_enabled

    @property
    def dns_proxy_ip(self):
        """
        Gets the dns_proxy_ip of this EnableReverseConnectionsDetails.
        The IP address in the service VCN to be used to reach the DNS proxy that resolves the
        customer FQDN for reverse connections. If no value is provided, an available IP address will
        be chosen from the service subnet's CIDR.


        :return: The dns_proxy_ip of this EnableReverseConnectionsDetails.
        :rtype: str
        """
        return self._dns_proxy_ip

    @dns_proxy_ip.setter
    def dns_proxy_ip(self, dns_proxy_ip):
        """
        Sets the dns_proxy_ip of this EnableReverseConnectionsDetails.
        The IP address in the service VCN to be used to reach the DNS proxy that resolves the
        customer FQDN for reverse connections. If no value is provided, an available IP address will
        be chosen from the service subnet's CIDR.


        :param dns_proxy_ip: The dns_proxy_ip of this EnableReverseConnectionsDetails.
        :type: str
        """
        self._dns_proxy_ip = dns_proxy_ip

    @property
    def default_dns_resolution_context(self):
        """
        Gets the default_dns_resolution_context of this EnableReverseConnectionsDetails.
        The context in which the DNS proxy will resolve the DNS queries. The default is `SERVICE`.

        For example: if the service does not know the specific DNS zones for the customer VCNs, set
        this to `CUSTOMER`, and set `excludedDnsZones` to the list of DNS zones in your service
        provider VCN.

        Allowed values:

         * `SERVICE`: All DNS queries will be resolved within the service VCN's DNS context,
           unless the FQDN belongs to one of zones in the `excludedDnsZones` list.

         * `CUSTOMER`: All DNS queries will be resolved within the customer VCN's DNS context,
           unless the FQDN belongs to one of zones in the `excludedDnsZones` list.

        Allowed values for this property are: "SERVICE", "CUSTOMER"


        :return: The default_dns_resolution_context of this EnableReverseConnectionsDetails.
        :rtype: str
        """
        return self._default_dns_resolution_context

    @default_dns_resolution_context.setter
    def default_dns_resolution_context(self, default_dns_resolution_context):
        """
        Sets the default_dns_resolution_context of this EnableReverseConnectionsDetails.
        The context in which the DNS proxy will resolve the DNS queries. The default is `SERVICE`.

        For example: if the service does not know the specific DNS zones for the customer VCNs, set
        this to `CUSTOMER`, and set `excludedDnsZones` to the list of DNS zones in your service
        provider VCN.

        Allowed values:

         * `SERVICE`: All DNS queries will be resolved within the service VCN's DNS context,
           unless the FQDN belongs to one of zones in the `excludedDnsZones` list.

         * `CUSTOMER`: All DNS queries will be resolved within the customer VCN's DNS context,
           unless the FQDN belongs to one of zones in the `excludedDnsZones` list.


        :param default_dns_resolution_context: The default_dns_resolution_context of this EnableReverseConnectionsDetails.
        :type: str
        """
        allowed_values = ["SERVICE", "CUSTOMER"]
        if not value_allowed_none_or_none_sentinel(default_dns_resolution_context, allowed_values):
            raise ValueError(
                "Invalid value for `default_dns_resolution_context`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._default_dns_resolution_context = default_dns_resolution_context

    @property
    def excluded_dns_zones(self):
        """
        Gets the excluded_dns_zones of this EnableReverseConnectionsDetails.
        List of DNS zones to exclude from the default DNS resolution context.


        :return: The excluded_dns_zones of this EnableReverseConnectionsDetails.
        :rtype: list[str]
        """
        return self._excluded_dns_zones

    @excluded_dns_zones.setter
    def excluded_dns_zones(self, excluded_dns_zones):
        """
        Sets the excluded_dns_zones of this EnableReverseConnectionsDetails.
        List of DNS zones to exclude from the default DNS resolution context.


        :param excluded_dns_zones: The excluded_dns_zones of this EnableReverseConnectionsDetails.
        :type: list[str]
        """
        self._excluded_dns_zones = excluded_dns_zones

    @property
    def service_subnet_id(self):
        """
        Gets the service_subnet_id of this EnableReverseConnectionsDetails.
        The `OCID`__ of the service's subnet where
        the DNS proxy endpoint will be created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The service_subnet_id of this EnableReverseConnectionsDetails.
        :rtype: str
        """
        return self._service_subnet_id

    @service_subnet_id.setter
    def service_subnet_id(self, service_subnet_id):
        """
        Sets the service_subnet_id of this EnableReverseConnectionsDetails.
        The `OCID`__ of the service's subnet where
        the DNS proxy endpoint will be created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param service_subnet_id: The service_subnet_id of this EnableReverseConnectionsDetails.
        :type: str
        """
        self._service_subnet_id = service_subnet_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
