# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConsumptionSummary(object):
    """
    The regional and AD specific limit consumption values.
    """

    #: A constant which can be used with the scope property of a ConsumptionSummary.
    #: This constant has a value of "REGION"
    SCOPE_REGION = "REGION"

    #: A constant which can be used with the scope property of a ConsumptionSummary.
    #: This constant has a value of "AVAILABILITY_DOMAIN"
    SCOPE_AVAILABILITY_DOMAIN = "AVAILABILITY_DOMAIN"

    def __init__(self, **kwargs):
        """
        Initializes a new ConsumptionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ConsumptionSummary.
        :type name: str

        :param scope:
            The value to assign to the scope property of this ConsumptionSummary.
            Allowed values for this property are: "REGION", "AVAILABILITY_DOMAIN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type scope: str

        :param value:
            The value to assign to the value property of this ConsumptionSummary.
        :type value: str

        """
        self.swagger_types = {
            'name': 'str',
            'scope': 'str',
            'value': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'scope': 'scope',
            'value': 'value'
        }

        self._name = None
        self._scope = None
        self._value = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ConsumptionSummary.
        The consumption name corresponding to the limit name.


        :return: The name of this ConsumptionSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConsumptionSummary.
        The consumption name corresponding to the limit name.


        :param name: The name of this ConsumptionSummary.
        :type: str
        """
        self._name = name

    @property
    def scope(self):
        """
        **[Required]** Gets the scope of this ConsumptionSummary.
        The scope of the consumption data.

        Allowed values for this property are: "REGION", "AVAILABILITY_DOMAIN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The scope of this ConsumptionSummary.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this ConsumptionSummary.
        The scope of the consumption data.


        :param scope: The scope of this ConsumptionSummary.
        :type: str
        """
        allowed_values = ["REGION", "AVAILABILITY_DOMAIN"]
        if not value_allowed_none_or_none_sentinel(scope, allowed_values):
            scope = 'UNKNOWN_ENUM_VALUE'
        self._scope = scope

    @property
    def value(self):
        """
        **[Required]** Gets the value of this ConsumptionSummary.
        The consumption value.


        :return: The value of this ConsumptionSummary.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConsumptionSummary.
        The consumption value.


        :param value: The value of this ConsumptionSummary.
        :type: str
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
