# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiOperation(object):
    """
    Details of each API operation for an Oracle Database release.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApiOperation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ApiOperation.
        :type name: str

        :param is_allowed:
            The value to assign to the is_allowed property of this ApiOperation.
        :type is_allowed: bool

        :param data_source:
            The value to assign to the data_source property of this ApiOperation.
        :type data_source: list[OperationFieldSummary]

        :param properties:
            The value to assign to the properties property of this ApiOperation.
        :type properties: list[OperationFieldSummary]

        """
        self.swagger_types = {
            'name': 'str',
            'is_allowed': 'bool',
            'data_source': 'list[OperationFieldSummary]',
            'properties': 'list[OperationFieldSummary]'
        }

        self.attribute_map = {
            'name': 'name',
            'is_allowed': 'isAllowed',
            'data_source': 'dataSource',
            'properties': 'properties'
        }

        self._name = None
        self._is_allowed = None
        self._data_source = None
        self._properties = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ApiOperation.
        Type of DB system operation.


        :return: The name of this ApiOperation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ApiOperation.
        Type of DB system operation.


        :param name: The name of this ApiOperation.
        :type: str
        """
        self._name = name

    @property
    def is_allowed(self):
        """
        **[Required]** Gets the is_allowed of this ApiOperation.
        True if API operation is allowed for an Oracle Database release.


        :return: The is_allowed of this ApiOperation.
        :rtype: bool
        """
        return self._is_allowed

    @is_allowed.setter
    def is_allowed(self, is_allowed):
        """
        Sets the is_allowed of this ApiOperation.
        True if API operation is allowed for an Oracle Database release.


        :param is_allowed: The is_allowed of this ApiOperation.
        :type: bool
        """
        self._is_allowed = is_allowed

    @property
    def data_source(self):
        """
        Gets the data_source of this ApiOperation.
        The DB system's source at the time of provisioning. The source can be a backup, a running database, or the new DB system itself (when the DB system is not provisioned from an existing database).


        :return: The data_source of this ApiOperation.
        :rtype: list[OperationFieldSummary]
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """
        Sets the data_source of this ApiOperation.
        The DB system's source at the time of provisioning. The source can be a backup, a running database, or the new DB system itself (when the DB system is not provisioned from an existing database).


        :param data_source: The data_source of this ApiOperation.
        :type: list[OperationFieldSummary]
        """
        self._data_source = data_source

    @property
    def properties(self):
        """
        Gets the properties of this ApiOperation.
        Lists the DB system properties that can be updated.


        :return: The properties of this ApiOperation.
        :rtype: list[OperationFieldSummary]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this ApiOperation.
        Lists the DB system properties that can be updated.


        :param properties: The properties of this ApiOperation.
        :type: list[OperationFieldSummary]
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
