# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseServiceResource(object):
    """
    Details of each database service resource and its corresponding operations.
    """

    #: A constant which can be used with the name property of a DatabaseServiceResource.
    #: This constant has a value of "DBSYSTEMS"
    NAME_DBSYSTEMS = "DBSYSTEMS"

    #: A constant which can be used with the name property of a DatabaseServiceResource.
    #: This constant has a value of "DBNODES"
    NAME_DBNODES = "DBNODES"

    #: A constant which can be used with the name property of a DatabaseServiceResource.
    #: This constant has a value of "DBHOMES"
    NAME_DBHOMES = "DBHOMES"

    #: A constant which can be used with the name property of a DatabaseServiceResource.
    #: This constant has a value of "DATABASES"
    NAME_DATABASES = "DATABASES"

    #: A constant which can be used with the name property of a DatabaseServiceResource.
    #: This constant has a value of "BACKUPS"
    NAME_BACKUPS = "BACKUPS"

    #: A constant which can be used with the name property of a DatabaseServiceResource.
    #: This constant has a value of "EXTERNALBACKUPJOBS"
    NAME_EXTERNALBACKUPJOBS = "EXTERNALBACKUPJOBS"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseServiceResource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DatabaseServiceResource.
            Allowed values for this property are: "DBSYSTEMS", "DBNODES", "DBHOMES", "DATABASES", "BACKUPS", "EXTERNALBACKUPJOBS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        :param api_operations:
            The value to assign to the api_operations property of this DatabaseServiceResource.
        :type api_operations: list[ApiOperation]

        """
        self.swagger_types = {
            'name': 'str',
            'api_operations': 'list[ApiOperation]'
        }

        self.attribute_map = {
            'name': 'name',
            'api_operations': 'apiOperations'
        }

        self._name = None
        self._api_operations = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this DatabaseServiceResource.
        Resource Name.

        Allowed values for this property are: "DBSYSTEMS", "DBNODES", "DBHOMES", "DATABASES", "BACKUPS", "EXTERNALBACKUPJOBS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this DatabaseServiceResource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DatabaseServiceResource.
        Resource Name.


        :param name: The name of this DatabaseServiceResource.
        :type: str
        """
        allowed_values = ["DBSYSTEMS", "DBNODES", "DBHOMES", "DATABASES", "BACKUPS", "EXTERNALBACKUPJOBS"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    @property
    def api_operations(self):
        """
        **[Required]** Gets the api_operations of this DatabaseServiceResource.
        The DB system operations.


        :return: The api_operations of this DatabaseServiceResource.
        :rtype: list[ApiOperation]
        """
        return self._api_operations

    @api_operations.setter
    def api_operations(self, api_operations):
        """
        Sets the api_operations of this DatabaseServiceResource.
        The DB system operations.


        :param api_operations: The api_operations of this DatabaseServiceResource.
        :type: list[ApiOperation]
        """
        self._api_operations = api_operations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
