# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbVersion(object):
    """
    The Oracle Database version details.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DbVersion object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this DbVersion.
        :type version: str

        :param is_preview_db_version:
            The value to assign to the is_preview_db_version property of this DbVersion.
        :type is_preview_db_version: bool

        :param storage_management:
            The value to assign to the storage_management property of this DbVersion.
        :type storage_management: list[StorageManagementFieldSummary]

        :param database_service_resources:
            The value to assign to the database_service_resources property of this DbVersion.
        :type database_service_resources: list[DatabaseServiceResource]

        """
        self.swagger_types = {
            'version': 'str',
            'is_preview_db_version': 'bool',
            'storage_management': 'list[StorageManagementFieldSummary]',
            'database_service_resources': 'list[DatabaseServiceResource]'
        }

        self.attribute_map = {
            'version': 'version',
            'is_preview_db_version': 'isPreviewDbVersion',
            'storage_management': 'storageManagement',
            'database_service_resources': 'databaseServiceResources'
        }

        self._version = None
        self._is_preview_db_version = None
        self._storage_management = None
        self._database_service_resources = None

    @property
    def version(self):
        """
        **[Required]** Gets the version of this DbVersion.
        A valid Oracle Database version.


        :return: The version of this DbVersion.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DbVersion.
        A valid Oracle Database version.


        :param version: The version of this DbVersion.
        :type: str
        """
        self._version = version

    @property
    def is_preview_db_version(self):
        """
        **[Required]** Gets the is_preview_db_version of this DbVersion.
        True if the Oracle Database software is a preview version.


        :return: The is_preview_db_version of this DbVersion.
        :rtype: bool
        """
        return self._is_preview_db_version

    @is_preview_db_version.setter
    def is_preview_db_version(self, is_preview_db_version):
        """
        Sets the is_preview_db_version of this DbVersion.
        True if the Oracle Database software is a preview version.


        :param is_preview_db_version: The is_preview_db_version of this DbVersion.
        :type: bool
        """
        self._is_preview_db_version = is_preview_db_version

    @property
    def storage_management(self):
        """
        **[Required]** Gets the storage_management of this DbVersion.
        List of the DB system StorageManagement summary field.


        :return: The storage_management of this DbVersion.
        :rtype: list[StorageManagementFieldSummary]
        """
        return self._storage_management

    @storage_management.setter
    def storage_management(self, storage_management):
        """
        Sets the storage_management of this DbVersion.
        List of the DB system StorageManagement summary field.


        :param storage_management: The storage_management of this DbVersion.
        :type: list[StorageManagementFieldSummary]
        """
        self._storage_management = storage_management

    @property
    def database_service_resources(self):
        """
        **[Required]** Gets the database_service_resources of this DbVersion.
        List of database service resources.


        :return: The database_service_resources of this DbVersion.
        :rtype: list[DatabaseServiceResource]
        """
        return self._database_service_resources

    @database_service_resources.setter
    def database_service_resources(self, database_service_resources):
        """
        Sets the database_service_resources of this DbVersion.
        List of database service resources.


        :param database_service_resources: The database_service_resources of this DbVersion.
        :type: list[DatabaseServiceResource]
        """
        self._database_service_resources = database_service_resources

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
