# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperationFieldSummary(object):
    """
    The database operation field summary.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OperationFieldSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this OperationFieldSummary.
        :type name: str

        :param is_allowed:
            The value to assign to the is_allowed property of this OperationFieldSummary.
        :type is_allowed: bool

        """
        self.swagger_types = {
            'name': 'str',
            'is_allowed': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'is_allowed': 'isAllowed'
        }

        self._name = None
        self._is_allowed = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OperationFieldSummary.
        The DB system or DB system resource operation name.


        :return: The name of this OperationFieldSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OperationFieldSummary.
        The DB system or DB system resource operation name.


        :param name: The name of this OperationFieldSummary.
        :type: str
        """
        self._name = name

    @property
    def is_allowed(self):
        """
        **[Required]** Gets the is_allowed of this OperationFieldSummary.
        True if operation is allowed for an Oracle Database release.


        :return: The is_allowed of this OperationFieldSummary.
        :rtype: bool
        """
        return self._is_allowed

    @is_allowed.setter
    def is_allowed(self, is_allowed):
        """
        Sets the is_allowed of this OperationFieldSummary.
        True if operation is allowed for an Oracle Database release.


        :param is_allowed: The is_allowed of this OperationFieldSummary.
        :type: bool
        """
        self._is_allowed = is_allowed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
