# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StorageManagementFieldSummary(object):
    """
    The DB system storage management field summary.
    """

    #: A constant which can be used with the name property of a StorageManagementFieldSummary.
    #: This constant has a value of "ASM"
    NAME_ASM = "ASM"

    #: A constant which can be used with the name property of a StorageManagementFieldSummary.
    #: This constant has a value of "LVM"
    NAME_LVM = "LVM"

    def __init__(self, **kwargs):
        """
        Initializes a new StorageManagementFieldSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this StorageManagementFieldSummary.
            Allowed values for this property are: "ASM", "LVM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        :param is_allowed:
            The value to assign to the is_allowed property of this StorageManagementFieldSummary.
        :type is_allowed: bool

        """
        self.swagger_types = {
            'name': 'str',
            'is_allowed': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'is_allowed': 'isAllowed'
        }

        self._name = None
        self._is_allowed = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this StorageManagementFieldSummary.
        The DB system's storage management option name.

        Allowed values for this property are: "ASM", "LVM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this StorageManagementFieldSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this StorageManagementFieldSummary.
        The DB system's storage management option name.


        :param name: The name of this StorageManagementFieldSummary.
        :type: str
        """
        allowed_values = ["ASM", "LVM"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    @property
    def is_allowed(self):
        """
        **[Required]** Gets the is_allowed of this StorageManagementFieldSummary.
        True if the enumerated storage management option (LVM or ASM) is allowed.


        :return: The is_allowed of this StorageManagementFieldSummary.
        :rtype: bool
        """
        return self._is_allowed

    @is_allowed.setter
    def is_allowed(self, is_allowed):
        """
        Sets the is_allowed of this StorageManagementFieldSummary.
        True if the enumerated storage management option (LVM or ASM) is allowed.


        :param is_allowed: The is_allowed of this StorageManagementFieldSummary.
        :type: bool
        """
        self._is_allowed = is_allowed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
