# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ListObjectVersions(object):
    """
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized,
    talk to an administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ListObjectVersions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_versions:
            The value to assign to the object_versions property of this ListObjectVersions.
        :type object_versions: list[ObjectVersionSummary]

        :param prefixes:
            The value to assign to the prefixes property of this ListObjectVersions.
        :type prefixes: list[str]

        :param continuation_token:
            The value to assign to the continuation_token property of this ListObjectVersions.
        :type continuation_token: str

        """
        self.swagger_types = {
            'object_versions': 'list[ObjectVersionSummary]',
            'prefixes': 'list[str]',
            'continuation_token': 'str'
        }

        self.attribute_map = {
            'object_versions': 'objectVersions',
            'prefixes': 'prefixes',
            'continuation_token': 'continuationToken'
        }

        self._object_versions = None
        self._prefixes = None
        self._continuation_token = None

    @property
    def object_versions(self):
        """
        **[Required]** Gets the object_versions of this ListObjectVersions.
        An array of object version summaries.


        :return: The object_versions of this ListObjectVersions.
        :rtype: list[ObjectVersionSummary]
        """
        return self._object_versions

    @object_versions.setter
    def object_versions(self, object_versions):
        """
        Sets the object_versions of this ListObjectVersions.
        An array of object version summaries.


        :param object_versions: The object_versions of this ListObjectVersions.
        :type: list[ObjectVersionSummary]
        """
        self._object_versions = object_versions

    @property
    def prefixes(self):
        """
        Gets the prefixes of this ListObjectVersions.
        Prefixes that are common to the results returned by the request if the request specified a delimiter.


        :return: The prefixes of this ListObjectVersions.
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """
        Sets the prefixes of this ListObjectVersions.
        Prefixes that are common to the results returned by the request if the request specified a delimiter.


        :param prefixes: The prefixes of this ListObjectVersions.
        :type: list[str]
        """
        self._prefixes = prefixes

    @property
    def continuation_token(self):
        """
        Gets the continuation_token of this ListObjectVersions.
        The token to use as a query parameter to obtain the next page of
        a truncated ListObjects(Versions) response. It will be present only if 'versions' were requested.


        :return: The continuation_token of this ListObjectVersions.
        :rtype: str
        """
        return self._continuation_token

    @continuation_token.setter
    def continuation_token(self, continuation_token):
        """
        Sets the continuation_token of this ListObjectVersions.
        The token to use as a query parameter to obtain the next page of
        a truncated ListObjects(Versions) response. It will be present only if 'versions' were requested.


        :param continuation_token: The continuation_token of this ListObjectVersions.
        :type: str
        """
        self._continuation_token = continuation_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
